summaryrefslogtreecommitdiffstats
path: root/vendor/paragonie/sodium_compat/lib/stream-xchacha20.php
diff options
context:
space:
mode:
authorAnton Luka Šijanec <anton@sijanec.eu>2024-05-27 13:08:29 +0200
committerAnton Luka Šijanec <anton@sijanec.eu>2024-05-27 13:08:29 +0200
commit75160b12821f7f4299cce7f0b69c83c1502ae071 (patch)
tree27e25e4ccaef45f0c58b22831164050d1af1d4db /vendor/paragonie/sodium_compat/lib/stream-xchacha20.php
parentprvi-commit (diff)
download1ka-75160b12821f7f4299cce7f0b69c83c1502ae071.tar
1ka-75160b12821f7f4299cce7f0b69c83c1502ae071.tar.gz
1ka-75160b12821f7f4299cce7f0b69c83c1502ae071.tar.bz2
1ka-75160b12821f7f4299cce7f0b69c83c1502ae071.tar.lz
1ka-75160b12821f7f4299cce7f0b69c83c1502ae071.tar.xz
1ka-75160b12821f7f4299cce7f0b69c83c1502ae071.tar.zst
1ka-75160b12821f7f4299cce7f0b69c83c1502ae071.zip
Diffstat (limited to 'vendor/paragonie/sodium_compat/lib/stream-xchacha20.php')
-rw-r--r--vendor/paragonie/sodium_compat/lib/stream-xchacha20.php102
1 files changed, 59 insertions, 43 deletions
diff --git a/vendor/paragonie/sodium_compat/lib/stream-xchacha20.php b/vendor/paragonie/sodium_compat/lib/stream-xchacha20.php
index 44a6b5b..ffeae33 100644
--- a/vendor/paragonie/sodium_compat/lib/stream-xchacha20.php
+++ b/vendor/paragonie/sodium_compat/lib/stream-xchacha20.php
@@ -1,43 +1,59 @@
-<?php
-
-if (!is_callable('sodium_crypto_stream_xchacha20')) {
- /**
- * @see ParagonIE_Sodium_Compat::crypto_stream_xchacha20()
- * @param int $len
- * @param string $nonce
- * @param string $key
- * @return string
- * @throws SodiumException
- * @throws TypeError
- */
- function sodium_crypto_stream_xchacha20($len, $nonce, $key)
- {
- return ParagonIE_Sodium_Compat::crypto_stream_xchacha20($len, $nonce, $key, true);
- }
-}
-if (!is_callable('sodium_crypto_stream_xchacha20_keygen')) {
- /**
- * @see ParagonIE_Sodium_Compat::crypto_stream_xchacha20_keygen()
- * @return string
- * @throws Exception
- */
- function sodium_crypto_stream_xchacha20_keygen()
- {
- return ParagonIE_Sodium_Compat::crypto_stream_xchacha20_keygen();
- }
-}
-if (!is_callable('sodium_crypto_stream_xchacha20_xor')) {
- /**
- * @see ParagonIE_Sodium_Compat::crypto_stream_xchacha20_xor()
- * @param string $message
- * @param string $nonce
- * @param string $key
- * @return string
- * @throws SodiumException
- * @throws TypeError
- */
- function sodium_crypto_stream_xchacha20_xor($message, $nonce, $key)
- {
- return ParagonIE_Sodium_Compat::crypto_stream_xchacha20_xor($message, $nonce, $key, true);
- }
-}
+<?php
+
+if (!is_callable('sodium_crypto_stream_xchacha20')) {
+ /**
+ * @see ParagonIE_Sodium_Compat::crypto_stream_xchacha20()
+ * @param int $len
+ * @param string $nonce
+ * @param string $key
+ * @return string
+ * @throws SodiumException
+ * @throws TypeError
+ */
+ function sodium_crypto_stream_xchacha20($len, $nonce, $key)
+ {
+ return ParagonIE_Sodium_Compat::crypto_stream_xchacha20($len, $nonce, $key, true);
+ }
+}
+if (!is_callable('sodium_crypto_stream_xchacha20_keygen')) {
+ /**
+ * @see ParagonIE_Sodium_Compat::crypto_stream_xchacha20_keygen()
+ * @return string
+ * @throws Exception
+ */
+ function sodium_crypto_stream_xchacha20_keygen()
+ {
+ return ParagonIE_Sodium_Compat::crypto_stream_xchacha20_keygen();
+ }
+}
+if (!is_callable('sodium_crypto_stream_xchacha20_xor')) {
+ /**
+ * @see ParagonIE_Sodium_Compat::crypto_stream_xchacha20_xor()
+ * @param string $message
+ * @param string $nonce
+ * @param string $key
+ * @return string
+ * @throws SodiumException
+ * @throws TypeError
+ */
+ function sodium_crypto_stream_xchacha20_xor($message, $nonce, $key)
+ {
+ return ParagonIE_Sodium_Compat::crypto_stream_xchacha20_xor($message, $nonce, $key, true);
+ }
+}
+if (!is_callable('sodium_crypto_stream_xchacha20_xor_ic')) {
+ /**
+ * @see ParagonIE_Sodium_Compat::crypto_stream_xchacha20_xor_ic()
+ * @param string $message
+ * @param string $nonce
+ * @param int $counter
+ * @param string $key
+ * @return string
+ * @throws SodiumException
+ * @throws TypeError
+ */
+ function sodium_crypto_stream_xchacha20_xor_ic($message, $nonce, $counter, $key)
+ {
+ return ParagonIE_Sodium_Compat::crypto_stream_xchacha20_xor_ic($message, $nonce, $counter, $key, true);
+ }
+}